==> wow_views-0.0.6.tar.gz: lib/compoment/view/ViewHTML.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_widget_from_html_core/flutter_widget_from_html_core.dart';
import 'package:wow_views/compoment/iAction.dart';
import 'package:wowit/common.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';


class ViewHTML {
  Widget getMainView(Map<String, dynamic> data) {
    var keyString = Methods.getString(data, 'nameProcedure');
    var dataReponse = Methods.getList(data['data'], keyString);
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    if(dataReponse.isNotEmpty){
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          if(Methods.getString(dataReponse[0], 'keyTitle').isNotEmpty)...[
            Text(Message.getMessage(
                Methods.getString(dataReponse[0], 'keyTitle')
            ),style: TextStyle(
              color: Common.colorAppbar,
              fontWeight: FontWeight.bold,
              fontSize: 18,
            ),),
            const SizedBox(height: 16,)
          ],
          HtmlWidget(
            Methods.getString(dataReponse[0], 'htmThongtin'),
            textStyle: const TextStyle(fontSize: 14),
            onTapUrl: (value) {
              print('onTap Link: $value');
              var dataSplit = value.split('?');

              if(dataSplit.length>=2){
                Map valueMap = {};
                var data = dataSplit[dataSplit.length-1].split('&');
                for(var item in data ){
                  var listItem = item.split('=');
                  if(listItem.length == 2) {
                    valueMap[listItem[0]] = listItem[1];
                  }
                }
                if(valueMap.isNotEmpty) {
                  iAction.goToViewById(
                      Methods.getInt(valueMap, 'idView'),
                      Methods.getInt(valueMap, 'id')
                  );
                }
              }
            },
          ),
        ],
      );
    }else {
      return Container();
    }

  }
}

==> wow_views-0.0.7.tar.gz: lib/compoment/view/ViewHTML.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_widget_from_html_core/flutter_widget_from_html_core.dart';
import 'package:wow_views/compoment/iAction.dart';
import 'package:wowit/common.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';


class ViewHTML {
  Widget getMainView(Map<String, dynamic> data,String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    if(dataReponse.isNotEmpty){
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          if(Methods.getString(dataReponse[0], 'keyTitle').isNotEmpty)...[
            Text(Message.getMessage(
                Methods.getString(dataReponse[0], 'keyTitle')
            ),style: TextStyle(
              color: Common.colorAppbar,
              fontWeight: FontWeight.bold,
              fontSize: 18,
            ),),
            const SizedBox(height: 16,)
          ],
          HtmlWidget(
            Methods.getString(dataReponse[0], 'htmThongtin'),
            textStyle: const TextStyle(fontSize: 14),
            onTapUrl: (value) {
              print('onTap Link: $value');
              var dataSplit = value.split('?');

              if(dataSplit.length>=2){
                Map valueMap = {};
                var data = dataSplit[dataSplit.length-1].split('&');
                for(var item in data ){
                  var listItem = item.split('=');
                  if(listItem.length == 2) {
                    valueMap[listItem[0]] = listItem[1];
                  }
                }
                if(valueMap.isNotEmpty) {
                  iAction.goToViewById(
                      Methods.getInt(valueMap, 'idView'),
                      Methods.getInt(valueMap, 'id')
                  );
                }
              }
            },
          ),
        ],
      );
    }else {
      return Container();
    }

  }
}
